@@ -14,21 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.arrow.vector;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.math.BigDecimal;
 import java.nio.ByteBuffer;
 import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import java.util.List;
-
 import org.apache.arrow.memory.BufferAllocator;
 import org.apache.arrow.vector.complex.FixedSizeListVector;
 import org.apache.arrow.vector.complex.ListVector;
@@ -41,29 +40,30 @@ import org.apache.arrow.vector.types.pojo.ArrowType;
 import org.apache.arrow.vector.types.pojo.FieldType;
 import org.apache.arrow.vector.util.Text;
 import org.apache.arrow.vector.util.TransferPair;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class TestFixedSizeListVector {
 
   private BufferAllocator allocator;
 
-  @Before
+  @BeforeEach
   public void init() {
     allocator = new DirtyRootAllocator(Long.MAX_VALUE, (byte) 100);
   }
 
-  @After
+  @AfterEach
   public void terminate() throws Exception {
     allocator.close();
   }
 
   @Test
   public void testIntType() {
-    try (FixedSizeListVector vector = FixedSizeListVector.empty("list", /*size=*/2, allocator)) {
-      IntVector nested = (IntVector) vector.addOrGetVector(FieldType.nullable(MinorType.INT.getType())).getVector();
+    try (FixedSizeListVector vector = FixedSizeListVector.empty("list", /*size=*/ 2, allocator)) {
+      IntVector nested =
+          (IntVector)
+              vector.addOrGetVector(FieldType.nullable(MinorType.INT.getType())).getVector();
       vector.allocateNew();
 
       for (int i = 0; i < 10; i++) {
@@ -76,12 +76,12 @@ public class TestFixedSizeListVector {
       UnionFixedSizeListReader reader = vector.getReader();
       for (int i = 0; i < 10; i++) {
         reader.setPosition(i);
-        Assert.assertTrue(reader.isSet());
-        Assert.assertTrue(reader.next());
+        assertTrue(reader.isSet());
+        assertTrue(reader.next());
         assertEquals(i, reader.reader().readInteger().intValue());
-        Assert.assertTrue(reader.next());
+        assertTrue(reader.next());
         assertEquals(i + 10, reader.reader().readInteger().intValue());
-        Assert.assertFalse(reader.next());
+        assertFalse(reader.next());
         assertEquals(Arrays.asList(i, i + 10), reader.readObject());
       }
     }
@@ -89,9 +89,10 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testFloatTypeNullable() {
-    try (FixedSizeListVector vector = FixedSizeListVector.empty("list", /*size=*/2, allocator)) {
-      Float4Vector nested = (Float4Vector) vector.addOrGetVector(FieldType.nullable(MinorType.FLOAT4.getType()))
-          .getVector();
+    try (FixedSizeListVector vector = FixedSizeListVector.empty("list", /*size=*/ 2, allocator)) {
+      Float4Vector nested =
+          (Float4Vector)
+              vector.addOrGetVector(FieldType.nullable(MinorType.FLOAT4.getType())).getVector();
       vector.allocateNew();
 
       for (int i = 0; i < 10; i++) {
@@ -107,16 +108,16 @@ public class TestFixedSizeListVector {
       for (int i = 0; i < 10; i++) {
         reader.setPosition(i);
         if (i % 2 == 0) {
-          Assert.assertTrue(reader.isSet());
-          Assert.assertTrue(reader.next());
+          assertTrue(reader.isSet());
+          assertTrue(reader.next());
           assertEquals(i + 0.1f, reader.reader().readFloat(), 0.00001);
-          Assert.assertTrue(reader.next());
+          assertTrue(reader.next());
           assertEquals(i + 10.1f, reader.reader().readFloat(), 0.00001);
-          Assert.assertFalse(reader.next());
+          assertFalse(reader.next());
           assertEquals(Arrays.asList(i + 0.1f, i + 10.1f), reader.readObject());
         } else {
-          Assert.assertFalse(reader.isSet());
-          Assert.assertNull(reader.readObject());
+          assertFalse(reader.isSet());
+          assertNull(reader.readObject());
         }
       }
     }
@@ -125,10 +126,12 @@ public class TestFixedSizeListVector {
   @Test
   public void testNestedInList() {
     try (ListVector vector = ListVector.empty("list", allocator)) {
-      FixedSizeListVector tuples = (FixedSizeListVector) vector.addOrGetVector(
-          FieldType.nullable(new ArrowType.FixedSizeList(2))).getVector();
-      IntVector innerVector = (IntVector) tuples.addOrGetVector(FieldType.nullable(MinorType.INT.getType()))
-          .getVector();
+      FixedSizeListVector tuples =
+          (FixedSizeListVector)
+              vector.addOrGetVector(FieldType.nullable(new ArrowType.FixedSizeList(2))).getVector();
+      IntVector innerVector =
+          (IntVector)
+              tuples.addOrGetVector(FieldType.nullable(MinorType.INT.getType())).getVector();
       vector.allocateNew();
 
       for (int i = 0; i < 10; i++) {
@@ -149,18 +152,18 @@ public class TestFixedSizeListVector {
         reader.setPosition(i);
         if (i % 2 == 0) {
           for (int j = 0; j < i % 7; j++) {
-            Assert.assertTrue(reader.next());
+            assertTrue(reader.next());
             FieldReader innerListReader = reader.reader();
             for (int k = 0; k < 2; k++) {
-              Assert.assertTrue(innerListReader.next());
+              assertTrue(innerListReader.next());
               assertEquals(k + j, innerListReader.reader().readInteger().intValue());
             }
-            Assert.assertFalse(innerListReader.next());
+            assertFalse(innerListReader.next());
           }
-          Assert.assertFalse(reader.next());
+          assertFalse(reader.next());
         } else {
-          Assert.assertFalse(reader.isSet());
-          Assert.assertNull(reader.readObject());
+          assertFalse(reader.isSet());
+          assertNull(reader.readObject());
         }
       }
     }
@@ -168,12 +171,18 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testTransferPair() {
-    try (FixedSizeListVector from = new FixedSizeListVector(
-        "from", allocator, new FieldType(true, new ArrowType.FixedSizeList(2), null), null);
-         FixedSizeListVector to = new FixedSizeListVector(
-             "to", allocator, new FieldType(true, new ArrowType.FixedSizeList(2), null), null)) {
-      Float4Vector nested = (Float4Vector) from.addOrGetVector(FieldType.nullable(MinorType.FLOAT4.getType()))
-          .getVector();
+    try (FixedSizeListVector from =
+            new FixedSizeListVector(
+                "from",
+                allocator,
+                new FieldType(true, new ArrowType.FixedSizeList(2), null),
+                null);
+        FixedSizeListVector to =
+            new FixedSizeListVector(
+                "to", allocator, new FieldType(true, new ArrowType.FixedSizeList(2), null), null)) {
+      Float4Vector nested =
+          (Float4Vector)
+              from.addOrGetVector(FieldType.nullable(MinorType.FLOAT4.getType())).getVector();
       from.allocateNew();
 
       for (int i = 0; i < 10; i++) {
@@ -196,53 +205,54 @@ public class TestFixedSizeListVector {
       UnionFixedSizeListReader reader = to.getReader();
 
       reader.setPosition(0);
-      Assert.assertFalse(reader.isSet());
-      Assert.assertNull(reader.readObject());
+      assertFalse(reader.isSet());
+      assertNull(reader.readObject());
 
       reader.setPosition(1);
-      Assert.assertTrue(reader.isSet());
-      Assert.assertTrue(reader.next());
+      assertTrue(reader.isSet());
+      assertTrue(reader.next());
       assertEquals(0.1f, reader.reader().readFloat(), 0.00001);
-      Assert.assertTrue(reader.next());
+      assertTrue(reader.next());
       assertEquals(10.1f, reader.reader().readFloat(), 0.00001);
-      Assert.assertFalse(reader.next());
+      assertFalse(reader.next());
       assertEquals(Arrays.asList(0.1f, 10.1f), reader.readObject());
 
       reader.setPosition(2);
-      Assert.assertTrue(reader.isSet());
-      Assert.assertTrue(reader.next());
+      assertTrue(reader.isSet());
+      assertTrue(reader.next());
       assertEquals(2.1f, reader.reader().readFloat(), 0.00001);
-      Assert.assertTrue(reader.next());
+      assertTrue(reader.next());
       assertEquals(12.1f, reader.reader().readFloat(), 0.00001);
-      Assert.assertFalse(reader.next());
+      assertFalse(reader.next());
       assertEquals(Arrays.asList(2.1f, 12.1f), reader.readObject());
 
       reader.setPosition(3);
-      Assert.assertTrue(reader.isSet());
-      Assert.assertTrue(reader.next());
+      assertTrue(reader.isSet());
+      assertTrue(reader.next());
       assertEquals(4.1f, reader.reader().readFloat(), 0.00001);
-      Assert.assertTrue(reader.next());
+      assertTrue(reader.next());
       assertEquals(14.1f, reader.reader().readFloat(), 0.00001);
-      Assert.assertFalse(reader.next());
+      assertFalse(reader.next());
       assertEquals(Arrays.asList(4.1f, 14.1f), reader.readObject());
 
       for (int i = 4; i < 10; i++) {
         reader.setPosition(i);
-        Assert.assertFalse(reader.isSet());
-        Assert.assertNull(reader.readObject());
+        assertFalse(reader.isSet());
+        assertNull(reader.readObject());
       }
     }
   }
 
   @Test
   public void testConsistentChildName() throws Exception {
-    try (FixedSizeListVector listVector = FixedSizeListVector.empty("sourceVector", /*size=*/2, allocator)) {
+    try (FixedSizeListVector listVector =
+        FixedSizeListVector.empty("sourceVector", /*size=*/ 2, allocator)) {
       String emptyListStr = listVector.getField().toString();
-      Assert.assertTrue(emptyListStr.contains(ListVector.DATA_VECTOR_NAME));
+      assertTrue(emptyListStr.contains(ListVector.DATA_VECTOR_NAME));
 
       listVector.addOrGetVector(FieldType.nullable(MinorType.INT.getType()));
       String emptyVectorStr = listVector.getField().toString();
-      Assert.assertTrue(emptyVectorStr.contains(ListVector.DATA_VECTOR_NAME));
+      assertTrue(emptyVectorStr.contains(ListVector.DATA_VECTOR_NAME));
     }
   }
 
@@ -252,7 +262,8 @@ public class TestFixedSizeListVector {
      * each list of size 3 and having its data values alternating between null and a non-null.
      * Read and verify
      */
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/3, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 3, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
@@ -280,7 +291,8 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testUnionFixedSizeListWriter() throws Exception {
-    try (final FixedSizeListVector vector1 = FixedSizeListVector.empty("vector", /*size=*/3, allocator)) {
+    try (final FixedSizeListVector vector1 =
+        FixedSizeListVector.empty("vector", /*size=*/ 3, allocator)) {
 
       UnionFixedSizeListWriter writer1 = vector1.getWriter();
       writer1.allocate();
@@ -289,7 +301,7 @@ public class TestFixedSizeListVector {
       int[] values2 = new int[] {4, 5, 6};
       int[] values3 = new int[] {7, 8, 9};
 
-      //set some values
+      // set some values
       writeListVector(vector1, writer1, values1);
       writeListVector(vector1, writer1, values2);
       writeListVector(vector1, writer1, values3);
@@ -308,7 +320,8 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testWriteDecimal() throws Exception {
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/3, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 3, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
@@ -336,50 +349,59 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testDecimalIndexCheck() throws Exception {
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/3, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 3, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
 
-      IllegalStateException e = assertThrows(IllegalStateException.class, () -> {
-        writer.startList();
-        writer.decimal().writeDecimal(new BigDecimal(1));
-        writer.decimal().writeDecimal(new BigDecimal(2));
-        writer.decimal().writeDecimal(new BigDecimal(3));
-        writer.decimal().writeDecimal(new BigDecimal(4));
-        writer.endList();
-      });
+      IllegalStateException e =
+          assertThrows(
+              IllegalStateException.class,
+              () -> {
+                writer.startList();
+                writer.decimal().writeDecimal(new BigDecimal(1));
+                writer.decimal().writeDecimal(new BigDecimal(2));
+                writer.decimal().writeDecimal(new BigDecimal(3));
+                writer.decimal().writeDecimal(new BigDecimal(4));
+                writer.endList();
+              });
       assertEquals("values at index 0 is greater than listSize 3", e.getMessage());
     }
   }
 
-
-  @Test(expected = IllegalStateException.class)
+  @Test
   public void testWriteIllegalData() throws Exception {
-    try (final FixedSizeListVector vector1 = FixedSizeListVector.empty("vector", /*size=*/3, allocator)) {
+    assertThrows(
+        IllegalStateException.class,
+        () -> {
+          try (final FixedSizeListVector vector1 =
+              FixedSizeListVector.empty("vector", /*size=*/ 3, allocator)) {
 
-      UnionFixedSizeListWriter writer1 = vector1.getWriter();
-      writer1.allocate();
+            UnionFixedSizeListWriter writer1 = vector1.getWriter();
+            writer1.allocate();
 
-      int[] values1 = new int[] {1, 2, 3};
-      int[] values2 = new int[] {4, 5, 6, 7, 8};
+            int[] values1 = new int[] {1, 2, 3};
+            int[] values2 = new int[] {4, 5, 6, 7, 8};
 
-      //set some values
-      writeListVector(vector1, writer1, values1);
-      writeListVector(vector1, writer1, values2);
-      writer1.setValueCount(3);
+            // set some values
+            writeListVector(vector1, writer1, values1);
+            writeListVector(vector1, writer1, values2);
+            writer1.setValueCount(3);
 
-      assertEquals(3, vector1.getValueCount());
-      int[] realValue1 = convertListToIntArray(vector1.getObject(0));
-      assertTrue(Arrays.equals(values1, realValue1));
-      int[] realValue2 = convertListToIntArray(vector1.getObject(1));
-      assertTrue(Arrays.equals(values2, realValue2));
-    }
+            assertEquals(3, vector1.getValueCount());
+            int[] realValue1 = convertListToIntArray(vector1.getObject(0));
+            assertTrue(Arrays.equals(values1, realValue1));
+            int[] realValue2 = convertListToIntArray(vector1.getObject(1));
+            assertTrue(Arrays.equals(values2, realValue2));
+          }
+        });
   }
 
   @Test
   public void testSplitAndTransfer() throws Exception {
-    try (final FixedSizeListVector vector1 = FixedSizeListVector.empty("vector", /*size=*/3, allocator)) {
+    try (final FixedSizeListVector vector1 =
+        FixedSizeListVector.empty("vector", /*size=*/ 3, allocator)) {
 
       UnionFixedSizeListWriter writer1 = vector1.getWriter();
       writer1.allocate();
@@ -388,7 +410,7 @@ public class TestFixedSizeListVector {
       int[] values2 = new int[] {4, 5, 6};
       int[] values3 = new int[] {7, 8, 9};
 
-      //set some values
+      // set some values
       writeListVector(vector1, writer1, values1);
       writeListVector(vector1, writer1, values2);
       writeListVector(vector1, writer1, values3);
@@ -410,7 +432,8 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testZeroWidthVector() {
-    try (final FixedSizeListVector vector1 = FixedSizeListVector.empty("vector", /*size=*/0, allocator)) {
+    try (final FixedSizeListVector vector1 =
+        FixedSizeListVector.empty("vector", /*size=*/ 0, allocator)) {
 
       UnionFixedSizeListWriter writer1 = vector1.getWriter();
       writer1.allocate();
@@ -420,7 +443,7 @@ public class TestFixedSizeListVector {
       int[] values3 = null;
       int[] values4 = new int[] {};
 
-      //set some values
+      // set some values
       writeListVector(vector1, writer1, values1);
       writeListVector(vector1, writer1, values2);
       writeListVector(vector1, writer1, values3);
@@ -441,7 +464,8 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testVectorWithNulls() {
-    try (final FixedSizeListVector vector1 = FixedSizeListVector.empty("vector", /*size=*/4, allocator)) {
+    try (final FixedSizeListVector vector1 =
+        FixedSizeListVector.empty("vector", /*size=*/ 4, allocator)) {
 
       UnionFixedSizeListWriter writer1 = vector1.getWriter();
       writer1.allocate();
@@ -451,7 +475,7 @@ public class TestFixedSizeListVector {
       List<Integer> values3 = null;
       List<Integer> values4 = Arrays.asList(7, 8, null, 9);
 
-      //set some values
+      // set some values
       writeListVector(vector1, writer1, values1);
       writeListVector(vector1, writer1, values2);
       writeListVector(vector1, writer1, values3);
@@ -473,7 +497,8 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testWriteVarCharHelpers() throws Exception {
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/4, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 4, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
@@ -492,7 +517,8 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testWriteLargeVarCharHelpers() throws Exception {
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/4, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 4, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
@@ -511,47 +537,65 @@ public class TestFixedSizeListVector {
 
   @Test
   public void testWriteVarBinaryHelpers() throws Exception {
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/4, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 4, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
 
       writer.startList();
       writer.writeVarBinary("row1,1".getBytes(StandardCharsets.UTF_8));
-      writer.writeVarBinary("row1,2".getBytes(StandardCharsets.UTF_8), 0,
+      writer.writeVarBinary(
+          "row1,2".getBytes(StandardCharsets.UTF_8),
+          0,
           "row1,2".getBytes(StandardCharsets.UTF_8).length);
       writer.writeVarBinary(ByteBuffer.wrap("row1,3".getBytes(StandardCharsets.UTF_8)));
-      writer.writeVarBinary(ByteBuffer.wrap("row1,4".getBytes(StandardCharsets.UTF_8)), 0,
+      writer.writeVarBinary(
+          ByteBuffer.wrap("row1,4".getBytes(StandardCharsets.UTF_8)),
+          0,
           "row1,4".getBytes(StandardCharsets.UTF_8).length);
       writer.endList();
 
-      assertEquals("row1,1", new String((byte[]) vector.getObject(0).get(0), StandardCharsets.UTF_8));
-      assertEquals("row1,2", new String((byte[]) vector.getObject(0).get(1), StandardCharsets.UTF_8));
-      assertEquals("row1,3", new String((byte[]) vector.getObject(0).get(2), StandardCharsets.UTF_8));
-      assertEquals("row1,4", new String((byte[]) vector.getObject(0).get(3), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,1", new String((byte[]) vector.getObject(0).get(0), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,2", new String((byte[]) vector.getObject(0).get(1), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,3", new String((byte[]) vector.getObject(0).get(2), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,4", new String((byte[]) vector.getObject(0).get(3), StandardCharsets.UTF_8));
     }
   }
 
   @Test
   public void testWriteLargeVarBinaryHelpers() throws Exception {
-    try (final FixedSizeListVector vector = FixedSizeListVector.empty("vector", /*size=*/4, allocator)) {
+    try (final FixedSizeListVector vector =
+        FixedSizeListVector.empty("vector", /*size=*/ 4, allocator)) {
 
       UnionFixedSizeListWriter writer = vector.getWriter();
       writer.allocate();
 
       writer.startList();
       writer.writeLargeVarBinary("row1,1".getBytes(StandardCharsets.UTF_8));
-      writer.writeLargeVarBinary("row1,2".getBytes(StandardCharsets.UTF_8), 0,
+      writer.writeLargeVarBinary(
+          "row1,2".getBytes(StandardCharsets.UTF_8),
+          0,
           "row1,2".getBytes(StandardCharsets.UTF_8).length);
       writer.writeLargeVarBinary(ByteBuffer.wrap("row1,3".getBytes(StandardCharsets.UTF_8)));
-      writer.writeLargeVarBinary(ByteBuffer.wrap("row1,4".getBytes(StandardCharsets.UTF_8)), 0,
+      writer.writeLargeVarBinary(
+          ByteBuffer.wrap("row1,4".getBytes(StandardCharsets.UTF_8)),
+          0,
           "row1,4".getBytes(StandardCharsets.UTF_8).length);
       writer.endList();
 
-      assertEquals("row1,1", new String((byte[]) vector.getObject(0).get(0), StandardCharsets.UTF_8));
-      assertEquals("row1,2", new String((byte[]) vector.getObject(0).get(1), StandardCharsets.UTF_8));
-      assertEquals("row1,3", new String((byte[]) vector.getObject(0).get(2), StandardCharsets.UTF_8));
-      assertEquals("row1,4", new String((byte[]) vector.getObject(0).get(3), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,1", new String((byte[]) vector.getObject(0).get(0), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,2", new String((byte[]) vector.getObject(0).get(1), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,3", new String((byte[]) vector.getObject(0).get(2), StandardCharsets.UTF_8));
+      assertEquals(
+          "row1,4", new String((byte[]) vector.getObject(0).get(3), StandardCharsets.UTF_8));
     }
   }
 
@@ -563,7 +607,8 @@ public class TestFixedSizeListVector {
     return values;
   }
 
-  private void writeListVector(FixedSizeListVector vector, UnionFixedSizeListWriter writer, int[] values) {
+  private void writeListVector(
+      FixedSizeListVector vector, UnionFixedSizeListWriter writer, int[] values) {
     writer.startList();
     if (values != null) {
       for (int v : values) {
@@ -575,7 +620,8 @@ public class TestFixedSizeListVector {
     writer.endList();
   }
 
-  private void writeListVector(FixedSizeListVector vector, UnionFixedSizeListWriter writer, List<Integer> values) {
+  private void writeListVector(
+      FixedSizeListVector vector, UnionFixedSizeListWriter writer, List<Integer> values) {
     writer.startList();
     if (values != null) {
       for (Integer v : values) {
@@ -590,5 +636,4 @@ public class TestFixedSizeListVector {
     }
     writer.endList();
   }
-
 }
